summaryrefslogtreecommitdiff
path: root/src/components/include/transport_manager/transport_manager_listener_empty.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/components/include/transport_manager/transport_manager_listener_empty.h')
-rw-r--r--src/components/include/transport_manager/transport_manager_listener_empty.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/components/include/transport_manager/transport_manager_listener_empty.h b/src/components/include/transport_manager/transport_manager_listener_empty.h
index f7843c9a68..ca6c573a06 100644
--- a/src/components/include/transport_manager/transport_manager_listener_empty.h
+++ b/src/components/include/transport_manager/transport_manager_listener_empty.h
@@ -71,9 +71,12 @@ class TransportManagerListenerEmpty : public TransportManagerListener {
/**
* @brief OnDeviceSwitchingStart allows to notify listener that device is
* going to switch its connection. This default implementation does nothing.
* @param device_uid the id of the device which has to be switched.
*/
- void OnDeviceSwitchingStart(const DeviceUID& device_uid) OVERRIDE {}
+ void OnDeviceSwitchingStart(const DeviceUID& device_uid_from,
+ const DeviceUID& device_uid_to) OVERRIDE {}
/**
* @brief OnDeviceSwitchingFinish notifies listener that device reconnection
@@ -71,9 +71,12 @@ class TransportManagerListenerEmpty : public TransportManagerListener {
* @brief OnDeviceSwitchingStart allows to notify listener that device is
* going to switch its connection. This default implementation does nothing.
- * @param device_uid the id of the device which has to be switched.
+ * @param device_uid_from the id of the device which has to switch its
+ * transport
+ * @param device_uid_to the id of the device on new transport
*/